From 6da8beaa5a2b78e785e5b6519894f8357002d916 Mon Sep 17 00:00:00 2001
From: Justin Pryzby <pryzbyj@telsasoft.com>
Date: Thu, 18 Apr 2024 15:40:44 -0500
Subject: [PATCH] doc review for ALTER TABLE ... SPLIT/MERGE PARTITION

---
 doc/src/sgml/ddl.sgml             |  4 ++--
 doc/src/sgml/ref/alter_table.sgml | 22 +++++++++++-----------
 2 files changed, 13 insertions(+), 13 deletions(-)

diff --git a/doc/src/sgml/ddl.sgml b/doc/src/sgml/ddl.sgml
index 026bfff70f3..01277b1d327 100644
--- a/doc/src/sgml/ddl.sgml
+++ b/doc/src/sgml/ddl.sgml
@@ -4384,7 +4384,7 @@ ALTER INDEX measurement_city_id_logdate_key
 
     <para>
      There is also an option for merging multiple table partitions into
-     a single partition using the
+     a single partition using
      <link linkend="sql-altertable-merge-partitions"><command>ALTER TABLE ... MERGE PARTITIONS</command></link>.
      This feature simplifies the management of partitioned tables by allowing
      users to combine partitions that are no longer needed as
@@ -4403,7 +4403,7 @@ ALTER TABLE measurement
 
     <para>
      Similarly to merging multiple table partitions, there is an option for
-     splitting a single partition into multiple using the
+     splitting a single partition into multiple partitions using
      <link linkend="sql-altertable-split-partition"><command>ALTER TABLE ... SPLIT PARTITION</command></link>.
      This feature could come in handy when one partition grows too big
      and needs to be split into multiple.  It's important to note that
diff --git a/doc/src/sgml/ref/alter_table.sgml b/doc/src/sgml/ref/alter_table.sgml
index fe36ff82e52..e52cfee840c 100644
--- a/doc/src/sgml/ref/alter_table.sgml
+++ b/doc/src/sgml/ref/alter_table.sgml
@@ -1136,16 +1136,16 @@ WITH ( MODULUS <replaceable class="parameter">numeric_literal</replaceable>, REM
       If the split partition is a DEFAULT partition, one of the new partitions must be DEFAULT.
       In case one of the new partitions or one of existing partitions is DEFAULT,
       new partitions <replaceable class="parameter">partition_name1</replaceable>,
-      <replaceable class="parameter">partition_name2</replaceable>, ... can have spaces
+      <replaceable class="parameter">partition_name2</replaceable>, ... can have gaps
       between partitions bounds.  If the partitioned table does not have a DEFAULT
       partition, the DEFAULT partition can be defined as one of the new partitions.
      </para>
      <para>
       In case new partitions do not contain a DEFAULT partition and the partitioned table
-      does not have a DEFAULT partition, the following must be true: sum bounds of
+      does not have a DEFAULT partition, the following must be true: the sum bounds of
       new partitions <replaceable class="parameter">partition_name1</replaceable>,
       <replaceable class="parameter">partition_name2</replaceable>, ... should be
-      equal to bound of split partition <replaceable class="parameter">partition_name</replaceable>.
+      equal to the bounds of split partition <replaceable class="parameter">partition_name</replaceable>.
       One of the new partitions <replaceable class="parameter">partition_name1</replaceable>,
       <replaceable class="parameter">partition_name2</replaceable>, ... can have
       the same name as split partition <replaceable class="parameter">partition_name</replaceable>
@@ -1168,24 +1168,24 @@ WITH ( MODULUS <replaceable class="parameter">numeric_literal</replaceable>, REM
 
     <listitem>
      <para>
-      This form merges several partitions into the one partition of the target table.
-      Hash-partitioning is not supported.  If DEFAULT partition is not in the
+      This form merges several partitions of the target table into a single partition.
+      Hash-partitioning is not supported.  If a DEFAULT partition is not in the
       list of partitions <replaceable class="parameter">partition_name1</replaceable>,
       <replaceable class="parameter">partition_name2</replaceable> [, ...]:
       <itemizedlist>
        <listitem>
         <para>
-         For range-partitioned tables it is necessary that the ranges
+         For range-partitioned tables, it is necessary that the ranges
          of the partitions <replaceable class="parameter">partition_name1</replaceable>,
          <replaceable class="parameter">partition_name2</replaceable> [, ...] can
-         be merged into one range without spaces and overlaps (otherwise an error
+         be merged into one range with neither gaps nor overlaps (otherwise an error
          will be generated).  The combined range will be the range for the partition
          <replaceable class="parameter">partition_name</replaceable>.
         </para>
        </listitem>
        <listitem>
         <para>
-         For list-partitioned tables the value lists of all partitions
+         For list-partitioned tables, the value lists of all partitions
          <replaceable class="parameter">partition_name1</replaceable>,
          <replaceable class="parameter">partition_name2</replaceable> [, ...] are
          combined and form the list of values of partition
@@ -1193,7 +1193,7 @@ WITH ( MODULUS <replaceable class="parameter">numeric_literal</replaceable>, REM
         </para>
        </listitem>
       </itemizedlist>
-      If DEFAULT partition is in the list of partitions <replaceable class="parameter">partition_name1</replaceable>,
+      If a DEFAULT partition is in the list of partitions <replaceable class="parameter">partition_name1</replaceable>,
       <replaceable class="parameter">partition_name2</replaceable> [, ...]:
       <itemizedlist>
        <listitem>
@@ -1204,8 +1204,8 @@ WITH ( MODULUS <replaceable class="parameter">numeric_literal</replaceable>, REM
        </listitem>
        <listitem>
         <para>
-         For range- and list-partitioned tables the ranges and lists of values
-         of the merged partitions can be any.
+         For range- and list-partitioned tables, the ranges and lists of values
+         of the merged partitions can be anything.
         </para>
        </listitem>
       </itemizedlist>
-- 
2.42.0

